@@ -41,7 +41,7 @@ class FineDiningLovers(AbstractScraper):
             instructions_parent = self.soup.find(
                 "div", {"class": "ante-body"}
             )
-            instructions = instructions_parent.findAll("li")
+            instructions = instructions_parent.findAll({"li", "p"})
 
         return "\n".join(
             [normalize_string(instruction.get_text()) for instruction in instructions]
